@@ -24,6 +24,8 @@ import colemen_string_utils as strUtils
 import utils.file as file
 import utils.objectUtils as obj
 import utils.file_write as write
+import utils.dir_compression as compression
+import utils.dir_search as search
 # import utils.file as f
 import utils.resources
 
@@ -813,14 +815,3 @@ def _parse_copy_data_from_obj(file_obj):
     return data
 
 
-# file = r"C:\Users\Colemen\Desktop\DAZ DOWNLOADS\poses"
-# get_files(file)
-# src = r"C:\Users\Colemen\Desktop\TEST_FOLDER\directoryMirrorTests\sourceDirectory"
-# dst = r"C:\Users\Colemen\Desktop\TEST_FOLDER\directoryMirrorTests\targetDirectory"
-# mirror(src, dst)
-
-# src = r"Z:\Structure\Ra9\2021"
-# start_time = time.time()
-# get_files_thread(src)
-# end_time = time.time()
-# print(f"indexing duration: {end_time - start_time}")
