@@ -155,14 +155,16 @@ def to_webp(src_path,**kwargs):
     '''
     delete_original_after = obj.get_kwarg(['delete after'], False, (bool), **kwargs)
     outputs = []
-    src_list = f.gen_path_list(src_path)    
+    src_list = f.gen_path_list(src_path)
     
     for path in src_list:
         if f.exists(path) is False:
             print(f"Could not find: {path}")
+        # print(f"meta_data: {meta_data}")
         output_path = _convert_image(path, "webp")
         if f.exists(output_path):
             outputs.append(output_path)
+            copy_meta_data(path,output_path)
             if delete_original_after is True:
                 if output_path != path:
                     f.delete(path)
@@ -170,6 +172,14 @@ def to_webp(src_path,**kwargs):
             
     return outputs
 
+def copy_meta_data(src_path,dst_path):
+    dst_data = f.image.get_meta(dst_path)
+    src_data = f.image.get_meta(src_path)
+    kws = f.image.get_keywords(src_data)
+    # print(f"kws: ",kws) 
+    dst_data['meta_data']['XMP:Subject'] = src_data['meta_data']['XMP:Subject']
+    f.image.save_file_obj(dst_data)
+
 def to_jpg(src_path,**kwargs):
     '''
         Convert an image or list of images to jpg.
@@ -339,3 +349,4 @@ def _convert_image(src_path,output_ext):
         except UnidentifiedImageError:
             print(f"Skipping file, could not convert: {src_path}.")
             return False
+
